@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-crossref
 version: 0.2.0.0
-id: pandoc-crossref-0.2.0.0-ccceb7ebb872f9fdc4b54f370b30f837
-key: pando_AjDV2bWi6oGIWE6ageKOjr
+id: pandoc-crossref-0.2.0.0-640cf9269155fd82d37d8f7af0407ec9
+key: pando_LchBmpM2gjcHTPRo5fUI4o
 license: GPL-2
 maintainer: root@livid.pp.ru
 synopsis: Pandoc filter for cross-references
@@ -32,7 +32,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.0
 data-dir: /usr/share/pandoc-crossref
-hs-libraries: HSpandoc-crossref-0.2.0.0-AjDV2bWi6oGIWE6ageKOjr
+hs-libraries: HSpandoc-crossref-0.2.0.0-LchBmpM2gjcHTPRo5fUI4o
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -42,12 +42,12 @@ depends:
     data-accessor-transformers-0.2.1.7-082e9d05eabfdcb5b212785d058bd96b
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-1.16.0.2-31f468e05a5caa86237ccb0bcb6308ba
-    pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
-    roman-numerals-0.5.1.5-e3bdc5830c32bed2d93467972766bc3b
+    pandoc-1.17.0.1-1c6da1ddfcd8a2619fb2ca103a269dd9
+    pandoc-types-1.16.1-0b1608b10c9621b9412cccf92ea53ad6
+    roman-numerals-0.5.1.5-895a0ef14eb8678de90c7da056b82bde
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
+    yaml-0.8.16-8e3a1d884bd629b7e4f9063e0e319626
 haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
 haddock-html: /usr/share/doc/pandoc-crossref/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
